@@ -1,4 +1,4 @@
-## Copyright (C) 2021 David Legland
+## Copyright (C) 2024 David Legland
 ## All rights reserved.
 ## 
 ## Redistribution and use in source and binary forms, with or without
@@ -59,30 +59,17 @@ function h = drawPoint(varargin)
 %     drawPoint([5*cos(t)+10 3*sin(t)+10], 'r+');
 %     axis equal;
 %
-%   See also
+%   See also 
 %     points2d, clipPoints
 
-%   ---------
-%   author : David Legland
-%   INRA - TPV URPOI - BIA IMASTE
-%   created the 31/10/2003.
-%
+% ------
+% Author: David Legland
+% E-mail: david.legland@inrae.fr
+% Created: 2003-10-31
+% Copyright 2003-2023 INRA - TPV URPOI - BIA IMASTE
 
-%   HISTORY
-%   23/02/2004 add more documentation. Manage different kind of inputs.
-%     Does not draw points outside visible area.
-%   26/02/2007 update processing of input arguments.
-%   30/04/2009 remove clipping of points (use clipPoints if necessary)
-%   2011-10-11 add management of axes handle
-%   2018-31-06 fix the bug reported in https://savannah.gnu.org/bugs/index.php?53659
-
-% extract handle of axis to draw on
-if isAxisHandle(varargin{1})
-    ax = varargin{1};
-    varargin(1) = [];
-else
-    ax = gca;
-end
+% extract handle of axis to draw in
+[ax, varargin] = parseAxisHandle(varargin{:});
 
 % extract point(s) coordinates
 if size(varargin{1}, 2) == 2
