@@ -1,4 +1,4 @@
-## Copyright (C) 2021 David Legland
+## Copyright (C) 2024 David Legland
 ## All rights reserved.
 ## 
 ## Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
 ## policies, either expressed or implied, of the copyright holders.
 
 function varargout = minDistancePoints(p1, varargin)
-% Minimal distance between several points.
+%MINDISTANCEPOINTS Minimal distance between several points.
 %
 %   DIST = minDistancePoints(PTS)
 %   Returns the minimum distance between all pairs of points in PTS. PTS
@@ -59,7 +59,6 @@ function varargout = minDistancePoints(p1, varargin)
 %   DIST(I) = distancePoints(PTS1(I,:), PTS2(J,:));
 %   for I comprised between 1 and the number of rows in PTS1.
 %
-%
 %   Examples:
 %   % minimal distance between random planar points
 %       points = rand(20,2)*100;
@@ -92,29 +91,15 @@ function varargout = minDistancePoints(p1, varargin)
 %     drawEdge([pts poly(inds,:)], 'k')
 %   
 %
-%   See Also
+%   See also 
 %     points2d, distancePoints, nndist, findClosestPoint, hausdorffDistance
 %
 
 % ------
 % Author: David Legland
-% e-mail: david.legland@inrae.fr
-% Copyright 2009 INRAE - Cepia Software Platform.
-% created the 15/06/2004.
-
-
-% HISTORY:
-% 22/06/2005 compute sqrt only at the end (faster), and change behaviour
-%   for 2 inputs: compute min distance for each point in PTS1. 
-%   Also add support for different norms.
-% 15/08/2005 make difference when 1 array or 2 arrays of points
-% 25/10/2006 also returns indices of closest points
-% 30/10/2006 generalize to points of any dimension
-% 28/08/2007 code cleanup, add comments and help
-% 01/02/2017 complete re-write by JuanPi Carbajal
-% 01/02/2017 fix bugs, update code, fix MLInt Warning (D. Legland)
-% 01/02/2017 remove use of vech
-
+% E-mail: david.legland@inrae.fr
+% Created: 2004-06-15
+% Copyright 2004-2023 INRAE - Cepia Software Platform
 
 %% Initialisations
 
@@ -129,7 +114,7 @@ if nargin == 1
     % specify only one array of points, not the norm
     p2 = p1;
 elseif nargin == 2
-    if isscalar (varargin{1})
+    if isscalar(varargin{1})
         % specify array of points and the norm
         n   = varargin{1};
         p2  = p1;
@@ -148,17 +133,17 @@ else
 end
 
 % number of points in each array
-n1  = size (p1, 1);
-n2  = size (p2, 1);
+n1  = size(p1, 1);
+n2  = size(p2, 1);
 
 % dimensionality of points
-d   = size (p1, 2);
+d   = size(p1, 2);
 
 
 %% Computation of distances
 
 % allocate memory
-dist = zeros (n1, n2);
+dist = zeros(n1, n2);
 
 % Compute difference of coordinate for each pair of point (n1-by-n2 array)
 % and for each dimension. -> dist is a n1-by-n2 array.
@@ -167,32 +152,32 @@ if n == inf
     % infinite norm corresponds to maximum absolute value of differences
     % in 2D: dist = max(abs(dx) + max(abs(dy));
     for i = 1:d
-        dist = max (dist, abs(bsxfun (@minus, p1(:,i), p2(:,i).')));
+        dist = max(dist, abs(bsxfun(@minus, p1(:,i), p2(:,i)')));
     end
 else
     for i = 1:d
-        dist = dist + abs (bsxfun (@minus, p1(:,i), p2(:,i).')).^n;
+        dist = dist + abs(bsxfun(@minus, p1(:,i), p2(:,i)')).^n;
     end
 end
-% TODO the previous could be optimized when a single array  is given (maybe!)
 
+% compute minimum distance, and indices
 if ~one_array
     % If two array of points where given
-    [minSqDist, ind]    = min (dist, [], 2);
-    minDist             = power (minSqDist, 1/n);
-    [ind2, ind1]        = ind2sub ([n1 n2], ind);
+    [minSqDist, ind]    = min(dist, [], 2);
+    minDist             = power(minSqDist, 1/n);
+    [ind2, ind1]        = ind2sub([n1 n2], ind);
     
 else
     % A single array was given
-    dist                = dist + diag (inf (n1,1)); % remove zeros from diagonal
-    dist                = dist (tril(true(n1, n1)));
-    [minSqDist, ind]    = min (dist); % index on packed lower triangular matrix
-    minDist             = power (minSqDist, 1/n);
+    dist                = dist + diag(inf(n1,1)); % remove zeros from diagonal
+    dist                = dist(tril(true(n1, n1)));
+    [minSqDist, ind]    = min(dist); % index on packed lower triangular matrix
+    minDist             = power(minSqDist, 1/n);
     
-    [ind2, ind1]        = ind2sub_tril (n1, ind);
+    [ind2, ind1]        = ind2sub_tril(n1, ind);
     ind2 = ind2(1);
     ind1 = ind1(1);
-    ind                 = sub2ind ([n1 n1], ind2, ind1);
+    ind                 = sub2ind([n1 n1], ind2, ind1);
 end
 
 
@@ -219,8 +204,9 @@ end
 end
 
 function [r, c] = ind2sub_tril (N, idx)
+% Convert a linear index to subscripts of a triangular matrix.
+%
 % [r, c] = ind2sub_tril (N, idx)
-% Convert a linear index to subscripts of a trinagular matrix.
 %
 % An example of triangular matrix linearly indexed follows
 %
@@ -244,19 +230,17 @@ function [r, c] = ind2sub_tril (N, idx)
 % when idx is a row or column matrix of linear indeces then r and
 % c have the same shape as idx.
 %
-% See also
-%   ind2sub
 
-endofrow = 0.5 * (1:N) .* (2*N:-1:N + 1);
-c = zeros(size(endofrow));
-for i = 1:length(endofrow)
-    ind = find(endofrow <= idx - 1, 1, 'last') + 1;
+endOfRow = 0.5 * (1:N) .* (2*N:-1:N + 1);
+c = zeros(size(endOfRow));
+for i = 1:length(endOfRow)
+    ind = find(endOfRow <= idx - 1, 1, 'last') + 1;
     if isempty(ind) 
         ind = 1;
     end
     c(i) = ind;
-% c        = lookup (endofrow, idx - 1) + 1;
 end
-r        = N - endofrow(c) + idx ;
+
+r = N - endOfRow(c) + idx ;
 
 end
