@@ -1,4 +1,4 @@
-## Copyright (C) 2021 David Legland
+## Copyright (C) 2024 David Legland
 ## All rights reserved.
 ## 
 ## Redistribution and use in source and binary forms, with or without
@@ -25,7 +25,7 @@
 ## those of the authors and should not be interpreted as representing official
 ## policies, either expressed or implied, of the copyright holders.
 
-function lengths = meshEdgeLength(vertices, edges, faces) %#ok<INUSD>
+function lengths = meshEdgeLength(varargin)
 %MESHEDGELENGTH Lengths of edges of a polygonal or polyhedral mesh.
 %
 %   output = meshEdgeLength(V, E, F)
@@ -33,14 +33,20 @@ function lengths = meshEdgeLength(vertices, edges, faces) %#ok<INUSD>
 %   Example
 %   meshEdgeLength
 %
-%   See also
-%
+%   See also 
 %
+
 % ------
 % Author: David Legland
-% e-mail: david.legland@grignon.inra.fr
-% Created: 2010-10-04,    using Matlab 7.9.0.529 (R2009b)
-% Copyright 2010 INRA - Cepia Software Platform.
+% E-mail: david.legland@inrae.fr
+% Created: 2010-10-04, using Matlab 7.9.0.529 (R2009b)
+% Copyright 2010-2023 INRA - Cepia Software Platform
+
+% parse input arguments
+[vertices, edges, faces] = parseMeshData(varargin{:});
+if isempty(edges)
+    edges = meshEdges(faces);
+end
 
 % extract vertices
 p1 = vertices(edges(:, 1), :);
